@@ -610,31 +610,42 @@ drcfit <- function(itemselect,
   dc$model <- modelnames[dc$model] 
   
   # Calculation of the theoretical value at the control : y0
+  # of the theoretical value at the maximal dose : yatdosemax
   # of the theoretical signal range on the range of tested concentration : yrange
+  # of the maximal change of y from its value at the minimal dose : maxychange
   # of the x-value that corresponds to the extremum for U and bell curves : xextrem
   ##################################################################################
   y0 <- numeric(length = nselect)
+  yatdosemax <- numeric(length = nselect)
   yrange <- numeric(length = nselect)
+  maxychange <- numeric(length = nselect)
   xextrem <- numeric(length = nselect)
   xextrem[1:nselect] <- NA # will remain at NA for monotonic curves
   yextrem <- numeric(length = nselect)
   yextrem[1:nselect] <- NA # will remain at NA for monotonic curves
   
-  # calculation of y0 and yrange for linear curves
+  # calculation of y0, maxychange and yrange for linear curves
   indlin <- which(dc$model == "linear")
   vb <- dc$b[indlin]
   vd <- dc$d[indlin]
-  yrange[indlin] <- abs(flin(dosemin, vb, vd) - flin(dosemax, vb, vd))
+  ydosemin <- flin(dosemin, vb, vd)
+  ydosemax <- flin(dosemax, vb, vd)
+  yatdosemax[indlin] <- ydosemax
+  yrange[indlin] <- abs(ydosemin - ydosemax)
   y0[indlin] <- vd
-
+  maxychange[indlin] <- yrange[indlin]
+  
   # calculation of y0 and yrange for exponential curves
   indExpo <- which(dc$model == "exponential")
   vb <- dc$b[indExpo]
   vd <- dc$d[indExpo]
   ve <- dc$e[indExpo]
-  yrange[indExpo] <- 
-    abs(fExpo(dosemin, vb, vd, ve) - fExpo(dosemax, vb, vd, ve))
+  ydosemin <- fExpo(dosemin, vb, vd, ve) 
+  ydosemax <- fExpo(dosemax, vb, vd, ve)
+  yatdosemax[indExpo] <- ydosemax
+  yrange[indExpo] <- abs(ydosemin - ydosemax)
   y0[indExpo] <- vd
+  maxychange[indExpo] <- yrange[indExpo]
   
   # calculation of y0 and yrange for Hill curves
   indHill <- which(dc$model == "Hill")
@@ -642,9 +653,12 @@ drcfit <- function(itemselect,
   vc <- dc$c[indHill]
   vd <- dc$d[indHill]
   ve <- dc$e[indHill]
-  yrange[indHill] <- 
-    abs(fHill(dosemin, vb, vc, vd, ve) - fHill(dosemax, vb, vc, vd, ve))
+  ydosemin <- fHill(dosemin, vb, vc, vd, ve)
+  ydosemax <- fHill(dosemax, vb, vc, vd, ve)
+  yatdosemax[indHill] <- ydosemax
+  yrange[indHill] <- abs(ydosemin - ydosemax)
   y0[indHill] <- vd
+  maxychange[indHill] <- yrange[indHill]
   
   # calculation of y0, xextrem and yrange for Gauss-probit curves
   # when f != 0
@@ -656,11 +670,13 @@ drcfit <- function(itemselect,
   vf <- dc$f[indGP]
   xextr <- xextrem[indGP] <- ve + (vc - vd)*vb/(vf*sqrt(2*pi)) 
   yextr <- yextrem[indGP] <- fGauss5p(xextr, vb, vc, vd, ve, vf)
-  yrange[indGP] <- pmax(
-    abs(fGauss5p(dosemin, vb, vc, vd, ve, vf) - yextr),
-    abs(yextr - fGauss5p(dosemax, vb, vc, vd, ve, vf))
-  )
+  ydosemin <- fGauss5p(dosemin, vb, vc, vd, ve, vf)
+  ydosemax <- fGauss5p(dosemax, vb, vc, vd, ve, vf)
+  yatdosemax[indGP] <- ydosemax
+  yrange[indGP] <- pmax(abs(ydosemin - yextr), abs(yextr - ydosemax))
+  maxychange[indGP] <- pmax(abs(ydosemin - yextr), abs(ydosemax - ydosemin))
   y0[indGP] <- fGauss5p(0, vb, vc, vd, ve, vf)
+  
   # when f == 0
   indGPf0 <- which((dc$model == "Gauss-probit" & dc$f == 0))
   vb <- dc$b[indGPf0]
@@ -668,9 +684,13 @@ drcfit <- function(itemselect,
   vd <- dc$d[indGPf0]
   ve <- dc$e[indGPf0]
   vf <- dc$f[indGPf0]
-  yrange[indGPf0] <- 
-    abs(fGauss5p(dosemin, vb, vc, vd, ve, vf) - fGauss5p(dosemax, vb, vc, vd, ve, vf))
+  ydosemin <- fGauss5p(dosemin, vb, vc, vd, ve, vf)
+  ydosemax <- fGauss5p(dosemax, vb, vc, vd, ve, vf)
+  yatdosemax[indGPf0] <- ydosemax
+  yrange[indGPf0] <- abs(ydosemin - ydosemax)
   y0[indGPf0] <- fGauss5p(0, vb, vc, vd, ve, vf)
+  maxychange[indGPf0] <- yrange[indGPf0]
+  
   
   # calculation of y0, xextrem and yrange for log-Gauss-probit curves
   # when f != 0
@@ -682,11 +702,13 @@ drcfit <- function(itemselect,
   vf <- dc$f[indlGP]
   xextr <- xextrem[indlGP] <- exp(log(ve) + (vc - vd)*vb/(vf*sqrt(2*pi))) 
   yextr <- yextrem[indlGP] <- fLGauss5p(xextr, vb, vc, vd, ve, vf) 
-  yrange[indlGP] <- pmax(
-    abs(fLGauss5p(dosemin, vb, vc, vd, ve, vf) - yextr),
-    abs(yextr - fLGauss5p(dosemax, vb, vc, vd, ve, vf))
-  )
+  ydosemin <- fLGauss5p(dosemin, vb, vc, vd, ve, vf)
+  ydosemax <- fLGauss5p(dosemax, vb, vc, vd, ve, vf)
+  yatdosemax[indlGP] <- ydosemax
+  yrange[indlGP] <- pmax(abs(ydosemin - yextr), abs(yextr - ydosemax))
+  maxychange[indlGP] <- pmax(abs(ydosemin - yextr), abs(ydosemax - ydosemin))
   y0[indlGP] <- vd
+  
   # when f == 0
   indlGPf0 <- which(dc$model == "log-Gauss-probit" & dc$f == 0)
   vb <- dc$b[indlGPf0]
@@ -694,9 +716,12 @@ drcfit <- function(itemselect,
   vd <- dc$d[indlGPf0]
   ve <- dc$e[indlGPf0]
   vf <- dc$f[indlGPf0]
-  yrange[indlGPf0] <- 
-    abs(fLGauss5p(dosemin, vb, vc, vd, ve, vf) - fLGauss5p(dosemax, vb, vc, vd, ve, vf))
+  ydosemin <- fLGauss5p(dosemin, vb, vc, vd, ve, vf)
+  ydosemax <- fLGauss5p(dosemax, vb, vc, vd, ve, vf)
+  yatdosemax[indlGPf0] <- ydosemax
+  yrange[indlGPf0] <- abs(ydosemin - ydosemax)
   y0[indlGPf0] <- vd
+  maxychange[indlGPf0] <- yrange[indlGPf0]
   
   
   # definition of trend and typology
@@ -790,7 +815,9 @@ drcfit <- function(itemselect,
   
   dc$trend <- factor(trend)
   dc$y0 <- y0
+  dc$yatdosemax <- yatdosemax
   dc$yrange <- yrange
+  dc$maxychange <- maxychange
   dc$xextrem <- xextrem
   dc$yextrem <- yextrem
   
