@@ -22,7 +22,7 @@ ecdfquantileplot <- function(variable, by, quantile.prob = 0.5, title)
   
   dnb <- as.data.frame(table(group))
   colnames(dnb) <- c("group", "nb_of_items")
-  quantilefun <- function(x) quantile(x, probs = quantile.prob)
+  quantilefun <- function(x) quantile(x, probs = quantile.prob, na.rm = FALSE)
   dnb$quantiles <- tapply(variable, group, quantilefun)
   dnb$ecdf <- (rank(dnb$quantiles) - 0.5) / nrow(dnb)
   # order by quantile
@@ -31,6 +31,7 @@ ecdfquantileplot <- function(variable, by, quantile.prob = 0.5, title)
   dnb$group <- factor(dnb$group, levels = dnb$group)
   g <- ggplot(dnb, aes_(x = quote(group), y = quote(quantiles), size = quote(nb_of_items))) + 
     geom_point(stat = 'identity')  +  
-    coord_flip() + labs(title = title)
+    coord_flip() + labs(title = title) +
+    scale_size_continuous(breaks = c(min(dnb$nb_of_items), median(dnb$nb_of_items), max(dnb$nb_of_items)))
   return(g)
 }
\ No newline at end of file
