@@ -8,12 +8,20 @@ if (visualize)
   data(Scenedesmus_metab)
   head(Scenedesmus_metab)
   set.seed(1234)
-  
-  # build of a dataset without control nor replicate
+
+  # build of a dataset without 0 nor replicate
   Scenedesmus_metab2 <- Scenedesmus_metab[, c(1,14:25)]
   Scenedesmus_metab2[1, -1] <- Scenedesmus_metab2[1, -1] * runif(11, 0.9, 1.1)
   head(Scenedesmus_metab2)
   
+  (oerror <- continuousomicdata(Scenedesmus_metab2)) ## should stop with an explicite error message
+  
+  # build of a dataset without replicate but with at least a 0
+  Scenedesmus_metab2 <- Scenedesmus_metab[, c(1,14:25)]
+  Scenedesmus_metab2[1, -1] <- Scenedesmus_metab2[1, -1] * runif(11, 0.9, 1.1)
+  Scenedesmus_metab2[1, -1] <- Scenedesmus_metab2[1, -1]* (Scenedesmus_metab2[1, -1] > 1)
+  head(Scenedesmus_metab2)
+  
   (o <- continuousomicdata(Scenedesmus_metab))
   plot(o)
   (s <- itemselect(o, select.method = "quadratic"))
@@ -35,7 +43,13 @@ if (visualize)
   Zhou2 <- Zhou[, c(1, 4:15)]
   Zhou2[1, -1] <- Zhou2[1, -1] * runif(11, 0.9, 1.1)
   head(Zhou2)
+  (oerror <- RNAseqdata(Zhou2))
   
+  # build of a dataset without replicate
+  Zhou2 <- Zhou[, c(1, 4:15)]
+  Zhou2[1, -1] <- Zhou2[1, -1] * runif(11, 0.9, 1.1)
+  Zhou2[1, -1] <- Zhou2[1, -1] * (Zhou2[1, -1] > 0.3)
+  head(Zhou2)
   (o <- RNAseqdata(Zhou))
   plot(o)
   (s <- itemselect(o, select.method = "quadratic"))
